import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import WhatsAppButton from "@/components/whatsapp-button";
import GestureWrapper from "@/components/gesture-wrapper";
import MobileNavigationIndicator from "@/components/mobile-navigation-indicator";
import TouchNavigationHelper from "@/components/touch-navigation";
import PageTransition from "@/components/page-transition";
import { useEffect, Suspense, lazy } from "react";
import Home from "@/pages/home";
import React from 'react';

// Lazy load pages to improve initial load time
const EventPhotography = lazy(() => import("@/pages/event-photography"));
const CommercialPhotography = lazy(() => import("@/pages/commercial-photography"));
const FineArtPhotography = lazy(() => import("@/pages/fine-art-photography"));
const FamilyPhotography = lazy(() => import("@/pages/family-photography"));
const BoudoirGallery = lazy(() => import("@/pages/boudoir-gallery"));
const Headshots = lazy(() => import("@/pages/headshots"));
const ProfessionalHeadshots = lazy(() => import("@/pages/professional-headshots"));
const RealEstatePhotography = lazy(() => import("@/pages/real-estate-photography"));
const BlogPage = lazy(() => import("@/pages/blog"));
const BlogPostTemplate = lazy(() => import("@/pages/blog-post"));
const BlogAdmin = lazy(() => import("@/pages/blog-admin"));
const NotFound = lazy(() => import("@/pages/not-found"));

// Mobile-optimized loading component
const PageLoader = () => (
  <div className="min-h-screen bg-gray-50 flex items-center justify-center">
    <div className="text-center">
      <div className="w-6 h-6 md:w-8 md:h-8 border-2 border-gray-300 border-t-gray-600 rounded-full animate-spin mx-auto mb-3"></div>
      <p className="text-gray-600 text-sm md:text-base">Loading...</p>
    </div>
  </div>
);

function Router() {
  return (
    <GestureWrapper style={{ minHeight: '100vh', touchAction: 'auto', overflowY: 'auto' }}>
      <Suspense fallback={<PageLoader />}>
        <PageTransition>
          <Switch>
            <Route path="/" component={Home} />
            <Route path="/event-photography" component={EventPhotography} />
            <Route path="/commercial-photography" component={CommercialPhotography} />
            <Route path="/fine-art-photography" component={FineArtPhotography} />
            <Route path="/family-photography" component={FamilyPhotography} />
            <Route path="/boudoir-gallery" component={BoudoirGallery} />
            <Route path="/headshots" component={Headshots} />
            <Route path="/professional-headshots" component={ProfessionalHeadshots} />
            <Route path="/real-estate-photography" component={RealEstatePhotography} />
            <Route path="/blog" component={BlogPage} />
            <Route path="/blog/:slug" component={BlogPostTemplate} />
            <Route path="/blog-admin" component={BlogAdmin} />
            <Route component={NotFound} />
          </Switch>
        </PageTransition>
      </Suspense>
      <MobileNavigationIndicator />
    </GestureWrapper>
  );
}

function App() {
  // Preload critical pages for faster navigation
  useEffect(() => {
    const isMobile = window.innerWidth < 768;
    
    const preloadPages = async () => {
      try {
        // Preload fewer pages on mobile to save bandwidth
        const pagesToPreload = isMobile 
          ? [import("@/pages/event-photography")]
          : [
              import("@/pages/event-photography"),
              import("@/pages/commercial-photography"),
              import("@/pages/family-photography")
            ];
            
        await Promise.all(pagesToPreload);
      } catch (error) {
        console.log("Page preloading failed:", error);
      }
    };
    
    // Longer delay on mobile to prioritize initial load
    const delay = isMobile ? 3000 : 2000;
    const timer = setTimeout(preloadPages, delay);
    return () => clearTimeout(timer);
  }, []);

  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <Toaster />
        <Router />
        <WhatsAppButton />
        <TouchNavigationHelper />
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;